# Notebooks

This directory contains the notebooks used to produce the `Book`s. Each notebook
corresponds with a single `Volume` (collection of `Book`s with the same `name`).

Each notebook also has a corresponding `.yaml` file containing the latest metadata
for the `Book`. See the `NotebookMetadata` schema(`bookshelf.schema.NotebookMetadata`)
for the expected format of this file.

For more details, see docs/source/notebooks.md
